import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface ProfileMappingConfig extends cdktf.TerraformMetaArguments {
    /**
    * Whether apply the changes to all users with this profile after updating or creating the these mappings.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#always_apply ProfileMapping#always_apply}
    */
    readonly alwaysApply?: boolean | cdktf.IResolvable;
    /**
    * When turned on this flag will trigger the provider to delete mapping properties that are not defined in config. By default, we do not delete missing properties.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#delete_when_absent ProfileMapping#delete_when_absent}
    */
    readonly deleteWhenAbsent?: boolean | cdktf.IResolvable;
    /**
    * The source id of the mapping to manage.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#source_id ProfileMapping#source_id}
    */
    readonly sourceId: string;
    /**
    * The target id of the mapping to manage.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#target_id ProfileMapping#target_id}
    */
    readonly targetId: string;
    /**
    * mappings block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#mappings ProfileMapping#mappings}
    */
    readonly mappings?: ProfileMappingMappings[] | cdktf.IResolvable;
}
export interface ProfileMappingMappings {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#expression ProfileMapping#expression}
    */
    readonly expression: string;
    /**
    * The mapping property key.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#id ProfileMapping#id}
    */
    readonly id: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping#push_status ProfileMapping#push_status}
    */
    readonly pushStatus?: string;
}
export declare function profileMappingMappingsToTerraform(struct?: ProfileMappingMappings | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping okta_profile_mapping}
*/
export declare class ProfileMapping extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/okta/r/profile_mapping okta_profile_mapping} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options ProfileMappingConfig
    */
    constructor(scope: Construct, id: string, config: ProfileMappingConfig);
    private _alwaysApply?;
    get alwaysApply(): boolean | cdktf.IResolvable;
    set alwaysApply(value: boolean | cdktf.IResolvable);
    resetAlwaysApply(): void;
    get alwaysApplyInput(): boolean | cdktf.IResolvable | undefined;
    private _deleteWhenAbsent?;
    get deleteWhenAbsent(): boolean | cdktf.IResolvable;
    set deleteWhenAbsent(value: boolean | cdktf.IResolvable);
    resetDeleteWhenAbsent(): void;
    get deleteWhenAbsentInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _sourceId?;
    get sourceId(): string;
    set sourceId(value: string);
    get sourceIdInput(): string | undefined;
    get sourceName(): string;
    get sourceType(): string;
    private _targetId?;
    get targetId(): string;
    set targetId(value: string);
    get targetIdInput(): string | undefined;
    get targetName(): string;
    get targetType(): string;
    private _mappings?;
    get mappings(): ProfileMappingMappings[] | cdktf.IResolvable;
    set mappings(value: ProfileMappingMappings[] | cdktf.IResolvable);
    resetMappings(): void;
    get mappingsInput(): cdktf.IResolvable | ProfileMappingMappings[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
